summaryrefslogtreecommitdiffstats
path: root/kopete/libkopete/kopeteawayaction.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-22 00:30:31 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-22 00:30:31 +0000
commit69cac65817d949cda2672ec4f0aa73d5e66a0ba1 (patch)
tree073fde0496ea90eb5bf5cffe66a8da43a9f55fbc /kopete/libkopete/kopeteawayaction.h
parent3467e6464beac3a162839bf7078e22e3a74d73e7 (diff)
downloadtdenetwork-69cac65817d949cda2672ec4f0aa73d5e66a0ba1.tar.gz
tdenetwork-69cac65817d949cda2672ec4f0aa73d5e66a0ba1.zip
TQt4 port kdenetwork
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdenetwork@1237912 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kopete/libkopete/kopeteawayaction.h')
-rw-r--r--kopete/libkopete/kopeteawayaction.h9
1 files changed, 5 insertions, 4 deletions
diff --git a/kopete/libkopete/kopeteawayaction.h b/kopete/libkopete/kopeteawayaction.h
index c787e7e7..6bc64581 100644
--- a/kopete/libkopete/kopeteawayaction.h
+++ b/kopete/libkopete/kopeteawayaction.h
@@ -40,26 +40,27 @@ class OnlineStatus;
class KOPETE_EXPORT AwayAction : public KSelectAction
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
* Constructor
* @p text, @p pix, @p cut, @p receiver, @p slot, @p parent and
* @p name are all handled by KSelectAction.
**/
AwayAction(const TQString &text, const TQIconSet &pix,
const KShortcut &cut, const TQObject *receiver, const char *slot,
- TQObject *parent, const char *name = 0);
+ TQObject *tqparent, const char *name = 0);
/**
* Constructor
* @param status the OnlineStatus that appears in the signal
* @param slot must have the following signature: ( const OnlineStatus &, const TQString & )
* @p text, @p pix, @p cut, @p receiver, @p slot, @p parent and
* @p name are all handled by KSelectAction.
**/
AwayAction(const OnlineStatus &status, const TQString &text, const TQIconSet &pix,
const KShortcut &cut, const TQObject *receiver, const char *slot,
- TQObject *parent, const char *name = 0);
+ TQObject *tqparent, const char *name = 0);
/**
* Destructor.
@@ -40,26 +40,27 @@ class OnlineStatus;
/**
* Constructor
- * @p text, @p pix, @p cut, @p receiver, @p slot, @p parent and
+ * @p text, @p pix, @p cut, @p receiver, @p slot, @p tqparent and
* @p name are all handled by KSelectAction.
**/
@@ -40,26 +40,27 @@ class OnlineStatus;
* @param status the OnlineStatus that appears in the signal
* @param slot must have the following signature: ( const OnlineStatus &, const TQString & )
- * @p text, @p pix, @p cut, @p receiver, @p slot, @p parent and
+ * @p text, @p pix, @p cut, @p receiver, @p slot, @p tqparent and
* @p name are all handled by KSelectAction.
**/